from collective.person.content.person import Person
from plone import api
from plone.dexterity.fti import DexterityFTI
from zope.component import createObject

import pytest


CONTENT_TYPE = "Person"


class TestPerson:
    @pytest.fixture(autouse=True)
    def _fti(self, get_fti, integration):
        self.fti = get_fti(CONTENT_TYPE)

    def test_fti(self):
        assert isinstance(self.fti, DexterityFTI)

    def test_factory(self):
        factory = self.fti.factory
        obj = createObject(factory)
        assert obj is not None
        assert isinstance(obj, Person)

    @pytest.mark.parametrize(
        "behavior",
        [
            "collective.person.person",
            "collective.contact_behaviors.contact_info",
            "volto.blocks.editable.layout",
            "plone.namefromtitle",
            "plone.shortname",
            "plone.excludefromnavigation",
            "plone.relateditems",
            "plone.versioning",
            "plone.leadimage",
        ],
    )
    def test_has_behavior(self, get_behaviors, behavior):
        assert behavior in get_behaviors(CONTENT_TYPE)

    def test_create(self, portal, persons_payload):
        payload = persons_payload[0]
        with api.env.adopt_roles(["Manager"]):
            content = api.content.create(container=portal, **payload)
        assert content.portal_type == CONTENT_TYPE
        assert isinstance(content, Person)

    def test_indexer_roles(self, portal, persons_payload):
        payload = persons_payload[0]
        brains = api.content.find(roles="member")
        assert len(brains) == 0

        with api.env.adopt_roles(["Manager"]):
            content = api.content.create(container=portal, **payload)

        brains = api.content.find(roles="member")
        assert len(brains) == 1
        assert brains[0].Title == content.title
